##trichter=vector
##untersuchungsgebiet=vector
##blindgaengerwsk=number 0.15
##threshold=number 1
##incomp_area=vector
##obsprob=number 0.5
##output=output vector

if (blindgaengerwsk > 1 | blindgaengerwsk < 0) {
stop("Blindgaengerwahrscheinlichkeit muss zwischen 0 und 1 gesetzt werden")
}

if (threshold < 0) {
stop("threshold (Naximal erwartete Anzahl an Blindgaengern pro Quadratkilometer an einem punkt ausserhalb der Sicherheitszone) muss fuer intensitaetsbasierte high-risk zone > 0 gesetzt werden")
}

if (obsprob > 1 | obsprob < 0) {
stop("obsprob (Beobachtungswahrscheinlichkeit in Einschraenkungsflaeche) muss zwischen 0 und 1 gesetzt werden")
}

library("highriskzone")
library("spatstat")
library("sf")

spatstat.options(npixel=750)

incomp_area <- as.owin(incomp_area)

trichter_dat = st_coordinates(trichter)
untersuchungsgebiet_dat = st_coordinates(untersuchungsgebiet)

hrzdat <- try(read_pppdata(xppp=trichter_dat[,"X"],
                           yppp=trichter_dat[,"Y"],
                           xwin=(untersuchungsgebiet_dat[,"X"]),
                           ywin=(untersuchungsgebiet_dat[,"Y"])), silent = TRUE)
if (class(hrzdat) == "try-error") {
  hrzdat <- (read_pppdata(xppp=trichter_dat[,"X"],
                          yppp=trichter_dat[,"Y"],
                          xwin=rev(untersuchungsgebiet_dat[,"X"]),
                          ywin=rev(untersuchungsgebiet_dat[,"Y"])))
}

inc_obs_ind <- which(point.in.polygon(hrzdat$x, hrzdat$y,
incomp_area$bdry[[1]]$x, incomp_area$bdry[[1]]$y) == 1)
obsprobs <- rep(1, times = length(hrzdat$x))
obsprobs[inc_obs_ind] <- obsprob

zone.a <- det_hrz_restr(hrzdat, type = "intens", criterion = "direct",
cutoff = threshold*1e-6, obsprobs = obsprobs, nxprob = blindgaengerwsk)

hrz <- zone.a$zone

if(sum(hrz$m==1, na.rm = TRUE)==0) {
stop(paste("Kein Ort im Untersuchungsgebiet weisst eine hoehere erwartete Anzahl an Blindgaengern pro Quadratkilometer als", threshold,"auf."))
}

hrz$m[is.na(hrz$m)] <- FALSE
output = st_as_sf(as.owin(hrz))
